################################################################################
## 
## Main script for reproducing 
## 
## PRWP: Fishing and Climate Change in Coastal Bangladesh
##   The Economic and Health Impacts of Increasing Salinity
##
## initial 2024
## revised February 2025
##
## Authors: Brian Blankespoor
##          Susmita Dasgupta*
##          Mainul Huq
##          Zahirul Huque Khan
##          Md. Golam Mustafa
##          David Wheeler
##
## Code:    Brian Blankespoor
##          David Wheeler*
##
################################################################################

install.packages("rstudioapi")
library(rstudioapi)

get_current_file_path <- function(){
  this_file <- grep("^--file=", commandArgs(), value = TRUE)
  this_file <- gsub("^--file=", "", this_file)
  if (length(this_file) == 0) this_file <- rstudioapi::getSourceEditorContext()$path
  return(dirname(this_file))
}

# set working directory
wkdir <- get_current_file_path()
print(wkdir)
setwd(wkdir)
getwd()

print(Sys.time())

# libraries, Rstata
source(file.path(wkdir,'biod_bgdcoast_wp_global_libraries.R'))

## Turn off sf's spherical ("S2") backend
sf_use_s2(FALSE) 
today <- Sys.Date()

# Run date
run_vers <- '2025-02-26'


tbldir <- file.path(wkdir,'tables_rp',sprintf("vers%s",run_vers)) # reproduced tables
figdir <- file.path(wkdir,'figures_rp',sprintf("vers%s",run_vers)) # reproduced figures
datdir <- file.path(wkdir,'local') # data directory
xfun::dir_create(tbldir)
xfun::dir_create(figdir)
xfun::dir_create(datdir)

print("Requires Stata and R")
print("User defined directories required")

# stata path here #
stata_path = '"C:/Program Files/Stata18/StataMP-64.exe"'


# load libraries
do_load_fn <- file.path(wkdir,'bgdcoast_load_libraries.do')
system(paste(stata_path, "/e do", do_load_fn),show.output.on.console = TRUE)

##
## Table 1: 
##


do_prep_table_1_fn <- file.path(wkdir,'bgdcoast_Table_1_Generate_Market_Fish_Species.do')
system(paste(stata_path, "/e do", do_prep_table_1_fn),show.output.on.console = TRUE)

##
## Table 2:
##

do_prep_table_2_fn <- file.path(wkdir,'bgdcoast_Table_2_GBIF_Species_Elasticites.do')
system(paste(stata_path, "/e do", do_prep_table_2_fn),show.output.on.console = TRUE)

##
## Table 3:
##

do_prep_table_3_fn <- file.path(wkdir,'bgdcoast_Table_3_Analyze_DHS.do')
system(paste(stata_path, "/e do", do_prep_table_3_fn),show.output.on.console = TRUE)

##
## Figures
##

## load boundary
source(file.path(wkdir,'biod_bgdcoast_wp_load_ddh_boundary_data.R'))

## Figure 1 and 3: Monthly mean salinity - Rupsha River, Khulna
do_prep_fig_01_fn <- file.path(wkdir,'bgdcoast_fig01_monthly_mean_salinity_khulna.do')
system(paste(stata_path, "/e do", do_prep_fig_01_fn),show.output.on.console = TRUE)

do_prep_fig_03_fn <- file.path(wkdir,'bgdcoast_fig03_monthly_mean_salinity.do')
system(paste(stata_path, "/e do", do_prep_fig_03_fn),show.output.on.console = TRUE)

## Figure 2a: River monitoring stations
source(file.path(wkdir,'biod_bgdcoast_wp_fig02a_stations.R'))

## Figure 2b: River monitoring stations
do_prep_fig_02b_fn <- file.path(wkdir,'bgdcoast_fig02_River_Monitor_Salinity_Table.do')
system(paste(stata_path, "/e do", do_prep_fig_02b_fn),show.output.on.console = TRUE)

## Figure 4: Locations of surveyed wholesale markets
source(file.path(wkdir,'biod_bgdcoast_wp_fig04_markets.R'))

## Figure 5 : Coilia dussumieri (Goldspotted Anchovy)
source(file.path(wkdir,'biod_bgdcoast_wp_fig05a_Coilia_dussumieri.R'))

## Figure 6: Mystus gulio (Gulio catfish)
source(file.path(wkdir,'biod_bgdcoast_wp_fig06a_Mystus_gulio.R'))

## Figure 7: Lates calcarifer (Lates perch)
source(file.path(wkdir,'biod_bgdcoast_wp_fig07a_Lates_calcarifer.R'))

## Figure 8:  (photos)

## Figure 9: Scomberomorus guttatus : catch quantity vs. salinity
## and
## Figure 10: Scomberomorus commerson : catch quantity vs. salinity
do_prep_fig09and10_fn <- file.path(wkdir,'bgdcoast_fig09and10_Species_Elasticity_Cases.do')
system(paste(stata_path, "/e do", do_prep_fig09and10_fn),show.output.on.console = TRUE)

## Figure 11: Total catch response to salinity change
do_prep_fig11_fn <- file.path(wkdir,'bgdcoast_fig11_Predict_Upazila_Species_Quantities.do')
system(paste(stata_path, "/e do", do_prep_fig11_fn),show.output.on.console = TRUE)

## Figure 12: Price impact of salinity change - high-price fish species
do_prep_fig12_fn <- file.path(wkdir,'bgdcoast_fig12_New_Price_Regressions.do')
system(paste(stata_path, "/e do", do_prep_fig12_fn),show.output.on.console = TRUE)

##
## Appendix
##

## Appendix Table A1: Econometric results for model (1)
do_prep_apptbl1_fn <- file.path(wkdir,'bgdcoast_Table_A1_GBIF_Species_Elasticites_Full.do')
system(paste(stata_path, "/e do", do_prep_apptbl1_fn),show.output.on.console = TRUE)
source(file.path(wkdir,'biod_bgdcoast_wp_A1_tbl.R'))

## Appendix Table A2: Econometric results for model (3)
do_prep_apptbl2_fn <- file.path(wkdir,'bgdcoast_Table_A2_Price_Regressions.do')
system(paste(stata_path, "/e do", do_prep_apptbl2_fn),show.output.on.console = TRUE)
source(file.path(wkdir,'biod_bgdcoast_wp_A2_tbl_lowprice.R'))
source(file.path(wkdir,'biod_bgdcoast_wp_A2_tbl_medprice.R'))
source(file.path(wkdir,'biod_bgdcoast_wp_A2_tbl_highprice.R'))

